@@ -175,7 +175,8 @@ class QAMProxy:
                  password='guest',
                  vhost='/',
                  client_id=None,
-                 serializer='pickle'):
+                 serializer='pickle',
+                 ssl=False):
                  
         if client_id == None:
             self.client_id = str(uuid.uuid4())
@@ -191,7 +192,8 @@ class QAMProxy:
                                                 port=port,
                                                 username=username,
                                                 password=password,
-                                                vhost=vhost)
+                                                vhost=vhost,
+                                                ssl=ssl)
 
    
         self.consumer_thread = ConsumerThread(amqp_credentials=self.amqp_credentials,
@@ -314,7 +316,7 @@ class QAMProxy:
             if self.consumer_thread.is_result_received(id):
                 return self.consumer_thread.get_result(id)
             else:
-                time.sleep(0.001)
+                time.sleep(0.1)
 
     def __getattr__(self, name):
         """
@@ -432,7 +434,7 @@ class SynchronTimeout:
             if self.parent.consumer_thread.is_result_received(id):
                 return self.parent.consumer_thread.get_result(id)
             else:
-                time.sleep(0.001)
+                time.sleep(0.1)
 
     def __getattr__(self, name):
         # magic method dispatcher
@@ -512,7 +514,8 @@ class ConsumerThread(Thread):
                                        port=amqp_credentials.port,
                                        userid=amqp_credentials.username,
                                        password=amqp_credentials.password,
-                                       host=amqp_credentials.vhost)
+                                       host=amqp_credentials.vhost,
+                                       ssl=amqp_credentials.ssl)
 
         self.consumer = Consumer(connection=self.amqpconn,
                                  queue=client_id + '_client_queue',
@@ -644,6 +647,7 @@ class ConsumerThread(Thread):
                 if self.result_list[result_id]['state'] != ConsumerThread.FREE:
                     self.result_list[result_id]['result_message'] = message_data
                     self.result_list[result_id]['state'] = ConsumerThread.DONE
+            time.sleep(0.1)
 #      else:
 #        time.sleep(0.001)
 
@@ -714,7 +718,8 @@ class PublisherThread(Thread):
                                        port=self.amqp_credentials.port,
                                        userid=self.amqp_credentials.username,
                                        password=self.amqp_credentials.password,
-                                       host=self.amqp_credentials.vhost)
+                                       host=self.amqp_credentials.vhost,
+                                       ssl=self.amqp_credentials.ssl)
 
         logger.debug('Serialization: %s' % self.serializer)
         self.publisher = Publisher(connection=self.amqpconn,
@@ -724,7 +729,7 @@ class PublisherThread(Thread):
     
         while self.kill == False:
             if len(self.method_queue) == 0:
-                time.sleep(0.001)
+                time.sleep(0.1)
                 continue
             method_message = self.method_queue.pop(0)
             self.publisher.send(method_message)
@@ -949,7 +954,7 @@ class CallbackObserverThread(Thread):
                                                                    uid)
                         exec_succes_thread.start()
             
-            time.sleep(0.001)
+            time.sleep(0.1)
 
 #===========================================================================
 
