@@ -128,7 +128,8 @@ class QAMServer:
                password='guest',
                vhost='/',
                server_id='testqamserver',
-               serializer='pickle'):
+               serializer='pickle',
+               ssl=False):
 
     """
     Initially the amqp-connection, a consumer and a publisher-thread are being created.
@@ -148,13 +149,15 @@ class QAMServer:
                                             port=port,
                                             username=username,
                                             password=password,
-                                            vhost=vhost)
+                                            vhost=vhost,
+                                            ssl=ssl)
 
     self.amqpconn = AMQPConnection(hostname=hostname,
                                    port=port,
                                    userid=username,
                                    password=password,
-                                   host=vhost)
+                                   host=vhost,
+                                   ssl=ssl)
 
     self.consumer = Consumer(connection=self.amqpconn,
                              queue=server_id + '_server_queue',
@@ -223,17 +226,17 @@ class QAMServer:
     """
     while not self.kill:
     #def execute_method(message_data, message):
-      message = self.consumer.fetch()
-      if message != None:
-        message_data = message.payload
-        message.ack()
-        execute_method_thread = ExecuteMethodThread(self.result_queue,
-                                                  message_data,
-                                                  self.method_dict,
-                                                  self.instance_dict,
-                                                  self.serializer)
-        execute_method_thread.start()
-
+          message = self.consumer.fetch()
+          if message != None:
+                message_data = message.payload
+                message.ack()
+                execute_method_thread = ExecuteMethodThread(self.result_queue,
+                                                      message_data,
+                                                      self.method_dict,
+                                                      self.instance_dict,
+                                                      self.serializer)
+                execute_method_thread.start()
+          time.sleep(0.1)
     self.finished = True
 
 
@@ -368,7 +371,8 @@ class PublisherThread(Thread):
                                    port=self.amqp_credentials.port,
                                    userid=self.amqp_credentials.username,
                                    password=self.amqp_credentials.password,
-                                   host=self.amqp_credentials.vhost)
+                                   host=self.amqp_credentials.vhost,
+                                   ssl=self.amqp_credentials.ssl)
     self.kill = False
     self.serializer = serializer
 
@@ -385,7 +389,7 @@ class PublisherThread(Thread):
     """
     while not self.kill:
       if len(self.result_queue) == 0:
-        time.sleep(0.001)
+        time.sleep(0.1)
         continue
       result_record = self.result_queue.pop(0)
       logger.debug('popped message from queue: %s' % repr(result_record['result_message']))
