@@ -77,6 +77,29 @@ class  QamTestCase(unittest.TestCase):
     #    self.foo.dispose()
     #    self.foo = None
 
+
+    def long_non_load_test(self):
+        print 'long_non_load_test'
+        proxy = QAMProxy(hostname=self.amqp_hostname,
+                         port=self.amqp_port,
+                         username=self.amqp_user,
+                         password=self.amqp_pwd,
+                         vhost=self.amqp_vhost,
+                         server_id='testqamserver',
+                         client_id='testqamclient1',
+                         serializer='json'
+                         )
+
+        for i in range(3):
+            time.sleep(5)
+            a = i
+            b = 1
+            golden_device = a + b
+            result = proxy.add(a, b)
+            self.assertEqual(golden_device, result, "%d + %d must equal %d" % (a, b, golden_device))
+
+        proxy.close()
+
     def test_basic_method_call(self):
         print 'test_basic_method_call'
         proxy = QAMProxy(hostname=self.amqp_hostname,
@@ -775,7 +798,7 @@ class  QamTestCase(unittest.TestCase):
 if __name__ == '__main__':
     unittest.main()
 #    result = unittest.TestResult()
-#    test = QamTestCase('test_callback_exception_method_call_pickle')
+#    test = QamTestCase('long_non_load_test')
 #    test.run(result)
 #    if len(result.failures) != 0: print "=============== Failures ==========================="
 #    print "".join("%s = %s" % (a, b) for a, b in result.failures)
